@@ -62,8 +62,8 @@ alkAgeDist <- function(key,lenA.n,len.n) {
   ## Some checks
   key <- iCheckALK(key)
   L <- nrow(key)
-  if (length(lenA.n)!=L) stop("'lenA.n' and the 'key' have different numbers of length intervals.",call.=FALSE)
-  if (length(len.n)!=L) stop("'len.n' and the 'key' have different numbers of length intervals.",call.=FALSE)
+  if (length(lenA.n)!=L) STOP("'lenA.n' and the 'key' have different numbers of length intervals.")
+  if (length(len.n)!=L) STOP("'len.n' and the 'key' have different numbers of length intervals.")
   
   ## total number of fish sampled
   N <- sum(len.n)
@@ -165,10 +165,10 @@ alkMeanVar <- function(key,formula,data,len.n,method=c("BettoliMiranda","QuinnDe
   method <- match.arg(method)
   key <- iCheckALK(key)
   tmp <- iHndlFormula(formula,data,expNumR=1,expNumE=2)
-  if (!tmp$metExpNumR) stop("'formula' must have a LHS with only one variable.",call.=FALSE)
-  if (!tmp$Rclass %in% c("numeric","integer")) stop ("LHS of 'formula' must be numeric.",call.=FALSE)
-  if (!tmp$metExpNumE) stop("'formula' must have two and only two variables on the RHS.",call.=FALSE)
-  if (length(len.n)!=nrow(key)) stop("'len.n' and the 'key' have different numbers of length intervals.",call.=FALSE)
+  if (!tmp$metExpNumR) STOP("'formula' must have a LHS with only one variable.")
+  if (!tmp$Rclass %in% c("numeric","integer")) stop ("LHS of 'formula' must be numeric.")
+  if (!tmp$metExpNumE) STOP("'formula' must have two and only two variables on the RHS.")
+  if (length(len.n)!=nrow(key)) STOP("'len.n' and the 'key' have different numbers of length intervals.")
   ## Main calculations (in internal functions)
   switch(method,
          BettoliMiranda= { res=iALKMean.BM(key,formula,data,N_i=len.n) },
