@@ -20,7 +20,7 @@
 #' \itemize{
 #'   \item von Bertalanffy
 #'   \itemize{
-#'     \item The \sQuote{Original} and \sQuote{vonBertalanffy} are synonymous as are \sQuote{Typical}, \sQuote{Traditional}, and \sQuote{BevertonHolt}.
+#'     \item The \sQuote{Original} and \sQuote{vonBertalanffy} are synonymous as are \sQuote{Typical}, \sQuote{Traditional}, and \sQuote{BevertonHolt}.  Further note that the \sQuote{Ogle} parameterization has the \sQuote{Original}/\sQuote{vonBertalanffy} and \sQuote{Typical}/\sQuote{Traditional}/\sQuote{BevertonHolt} parameterizations as special cases.
 #'   }
 #'   \item Gompertz
 #'   \itemize{
@@ -155,7 +155,7 @@
 #' ##   However, observe the correlations in the summary() results.
 #' 
 #' ## Von B
-#' data(SpotVA1) 
+#' data(SpotVA1)
 #' # Fitting the typical paramaterization of the von B function
 #' fit1 <- nls(tl~vb1(age,Linf,K,t0),data=SpotVA1,start=vbStarts(tl~age,data=SpotVA1))
 #' summary(fit1,correlation=TRUE)
@@ -279,27 +279,38 @@ NULL
 #' @export
 vbFuns <- function(param=c("Typical","typical","Traditional","traditional","BevertonHolt",
                           "Original","original","vonBertalanffy",
-                          "GQ","GallucciQuinn","Mooij","Weisberg",
+                          "GQ","GallucciQuinn","Mooij","Weisberg","Ogle",
                           "Schnute","Francis","Laslett","Polacheck",
                           "Somers","Somers2","Pauly",
                           "Fabens","Fabens2","Wang","Wang2","Wang3"),
                    simple=FALSE,msg=FALSE) {
+  Ogle <- function(t,Linf,K=NULL,tr=NULL,Lr=NULL) {
+    if (length(Linf)==4) {
+    Lr <- Linf[[4]]
+    tr <- Linf[[3]]
+    K <- Linf[[2]]
+    Linf <- Linf[[1]] }
+    Lr+(Linf-Lr)*(1-exp(-K*(t-tr)))
+  }
+  SOgle <- function(t,Linf,K,tr,Lr) {
+    Lr+(Linf-Lr)*(1-exp(-K*(t-tr)))
+  }
   Typical <- typical <- Traditional <- traditional <- BevertonHolt <- function(t,Linf,K=NULL,t0=NULL) {
   if (length(Linf)==3) { K <- Linf[[2]]
                          t0 <- Linf[[3]]
                          Linf <- Linf[[1]] }
   Linf*(1-exp(-K*(t-t0)))
-}
+  }
   STypical <- Stypical <- STraditional <- Straditional <- SBevertonHolt <- function(t,Linf,K,t0) {
     Linf*(1-exp(-K*(t-t0)))
   }
-  Original <- original <- vonBertalanffy <- function(t,Linf,L0=NULL,K=NULL) {
-  if (length(Linf)==3) { L0 <- Linf[[2]]
-                         K <- Linf[[3]]
+  Original <- original <- vonBertalanffy <- function(t,Linf,K=NULL,L0=NULL) {
+  if (length(Linf)==3) { K <- Linf[[2]]
+                         L0 <- Linf[[3]]
                          Linf <- Linf[[1]] }
   Linf-(Linf-L0)*exp(-K*t)
-}
-  SOriginal <- Soriginal <- SvonBertalanffy <- function(t,Linf,L0,K) {
+  }
+  SOriginal <- Soriginal <- SvonBertalanffy <- function(t,Linf,K,L0) {
     Linf-(Linf-L0)*exp(-K*t)
   }
   GQ <- GallucciQuinn <- function(t,omega,K=NULL,t0=NULL) {
@@ -307,7 +318,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
                           t0 <- omega[[3]]
                           omega <- omega[[1]] }
   (omega/K)*(1-exp(-K*(t-t0)))
-}
+  }
   SGQ <- SGallucciQuinn <- function(t,omega,K,t0) {
     (omega/K)*(1-exp(-K*(t-t0)))
   }
@@ -316,7 +327,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
                          omega <- Linf[[3]]
                          Linf <- Linf[[1]] }
   Linf-(Linf-L0)*exp(-(omega/Linf)*t)
-}
+  }
   SMooij <- function(t,Linf,L0,omega) {
     Linf-(Linf-L0)*exp(-(omega/Linf)*t)
   }
@@ -325,7 +336,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
                          t0 <- Linf[[3]]
                          Linf <- Linf[[1]] }
   Linf*(1-exp(-(log(2)/(t50-t0))*(t-t0)))
-}
+  }
   SWeisberg <- function(t,Linf,t50,t0) {
     Linf*(1-exp(-(log(2)/(t50-t0))*(t-t0)))
   } 
@@ -333,7 +344,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
   if (length(L1)==3) { L3 <- L1[[2]]; K <- L1[[3]]; L1 <- L1[[1]] }
   if (length(t1)==2) { t3 <- t1[[2]]; t1 <- t1[[1]] }
   L1+(L3-L1)*((1-exp(-K*(t-t1)))/(1-exp(-K*(t3-t1))))
-}
+  }
   SSchnute <- function(t,L1,L3,K,t1,t3) {
     L1+(L3-L1)*((1-exp(-K*(t-t1)))/(1-exp(-K*(t3-t1))))
   }
@@ -342,7 +353,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
   if (length(t1)==2) { t3 <- t1[[2]]; t1 <- t1[[1]] }
   r <- (L3-L2)/(L2-L1)
   L1+(L3-L1)*((1-r^(2*((t-t1)/(t3-t1))))/(1-r^2))
-}
+  }
   SFrancis <- function(t,L1,L2,L3,t1,t3) {
     r <- (L3-L2)/(L2-L1)
     L1+(L3-L1)*((1-r^(2*((t-t1)/(t3-t1))))/(1-r^2))
@@ -363,7 +374,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
   St <- (C*K)/(2*pi)*sin(2*pi*(t-ts))
   Sto <- (C*K)/(2*pi)*sin(2*pi*(t0-ts))
   Linf*(1-exp(-K*(t-t0)-St+Sto))
-}
+  }
   SSomers <- function(t,Linf,K,t0,C,ts) {
     Linf*(1-exp(-K*(t-t0)-(C*K)/(2*pi)*sin(2*pi*(t-ts))+(C*K)/(2*pi)*sin(2*pi*(t0-ts))))
   }
@@ -374,7 +385,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
   Rt <- (C*K)/(2*pi)*sin(2*pi*(t-WP+0.5))
   Rto <- (C*K)/(2*pi)*sin(2*pi*(t0-WP+0.5))
   Linf*(1-exp(-K*(t-t0)-Rt+Rto))
-}
+  }
   SSomers2 <- function(t,Linf,K,t0,C,WP) {
     Linf*(1-exp(-K*(t-t0)-(C*K)/(2*pi)*sin(2*pi*(t-WP+0.5))+(C*K)/(2*pi)*sin(2*pi*(t0-WP+0.5))))
   }
@@ -398,14 +409,14 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
   Fabens <- function(Lm,dt,Linf,K) {
   if (length(Linf)==2) { K <- Linf[[2]]; Linf <- Linf[[1]] }
   Lm+(Linf-Lm)*(1-exp(-K*dt))
-}
+  }
   SFabens <- function(Lm,dt,Linf,K) {
     Lm+(Linf-Lm)*(1-exp(-K*dt))
   }
   Fabens2 <- function(Lm,dt,Linf,K) {
   if (length(Linf)==2) { K <- Linf[[2]]; Linf <- Linf[[1]] }
   (Linf-Lm)*(1-exp(-K*dt))
-}
+  }
   SFabens2 <- function(Lm,dt,Linf,K) {
     (Linf-Lm)*(1-exp(-K*dt))
   }
@@ -413,7 +424,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
   if (length(Linf)==3) { b <- Linf[[3]]; K <- Linf[[2]]
                          Linf <- Linf[[1]] }
   (Linf+b*(Lm-mean(Lm))-Lm)*(1-exp(-K*dt))
-}
+  }
   SWang <- function(Lm,dt,Linf,K,b) {
     (Linf+b*(Lm-mean(Lm))-Lm)*(1-exp(-K*dt))
   }
@@ -434,6 +445,15 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
   param <- match.arg(param)
   if (msg) {
     switch(param,
+      Ogle= {
+        message("You have chosen the 'Ogle-Isermann' parameterization.\n\n",
+                "  E[L|t] = (Linf-Lr)*(1-exp(-K*(t-tr)))\n\n",
+                "  where Linf = asymptotic mean length\n",
+                "           K = exponential rate of approach to Linf\n",
+                "          tr = mean age at Lr\n",
+                "          Lr = mean length at tr\n\n",
+                "NOTE: either tr or Lr must be set by the user.\n\n")
+      },
       Typical=,typical=,Traditional=,traditional=,BevertonHolt= {
         message("You have chosen the 'Typical', 'Traditional', or 'BevertonHolt' parameterization.\n\n",
                 "  E[L|t] = Linf*(1-exp(-K*(t-t0)))\n\n",
@@ -524,9 +544,9 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
       },
       Pauly={
         message("You have chosen the 'Pauly Seasonal Cessation' parameterization.\n\n",
-                "  E[L|t] = Linf*(1-exp(-K'*(t'-to)-Vt'+St0))\n\n",
-                "  where vt' = (K'(1-NGT)/2*pi)*sin(2*pi*(t'-ts)/(1-NGT)) and\n",
-                "        vt0 = (K'(1-NGT)/2*pi)*sin(2*pi*(t0-ts)/(1-NGT)) and\n\n",
+                "  E[L|t] = Linf*(1-exp(-K'*(t'-to)-Vt'+Vt0))\n\n",
+                "  where Vt' = (K'(1-NGT)/2*pi)*sin(2*pi*(t'-ts)/(1-NGT)) and\n",
+                "        Vt0 = (K'(1-NGT)/2*pi)*sin(2*pi*(t0-ts)/(1-NGT)) and\n\n",
                 "  and Linf = asymptotic mean length\n",
                 "        K' = exponential rate of approach to Linf during growth period\n",
                 "        t0 = the theoretical age when length = 0 (a modeling artifact)\n",
@@ -582,7 +602,7 @@ vbFuns <- function(param=c("Typical","typical","Traditional","traditional","Beve
       }
     )
   }
-  if (simple) param <- paste("S",param,sep="")
+  if (simple) param <- paste0("S",param)
   get(param)
 }
 
@@ -717,7 +737,7 @@ GompertzFuns <- function(param=c("Ricker1","Ricker2","Ricker3",
            }
     )
   }
-  if (simple) param <- paste("S",param,sep="")
+  if (simple) param <- paste0("S",param)
   get(param)
 }
 
@@ -789,7 +809,7 @@ RichardsFuns <- function(param=1,simple=FALSE,msg=FALSE) {
     Lninf+(Linf-Lninf)*(1+(b-1)*exp(-k*(t-ti)))^(1/(1-b))
   }
   ## Main function
-  if (!param %in% 1:6) stop("'param' must be in 1:6.")
+  if (!param %in% 1:6) STOP("'param' must be in 1:6.")
   param <- paste0("Richards",param)
   if (msg) {
     switch(param,
@@ -844,7 +864,7 @@ RichardsFuns <- function(param=1,simple=FALSE,msg=FALSE) {
            }
     )
   }
-  if (simple) param <- paste("S",param,sep="")
+  if (simple) param <- paste0("S",param)
   get(param)
 }
 
@@ -927,7 +947,7 @@ logisticFuns <- function(param=c("CJ1","CJ2","Karkach","Haddon","CampanaJones1",
            }
     )
   }
-  if (simple) param <- paste("S",param,sep="")
+  if (simple) param <- paste0("S",param)
   get(param)
 }
 
@@ -983,26 +1003,26 @@ logisticFuns <- function(param=c("CJ1","CJ2","Karkach","Haddon","CampanaJones1",
 Schnute <- function(t,case=1,t1=NULL,t3=NULL,L1=NULL,L3=NULL,a=NULL,b=NULL) {
   ## check case
   case <- as.character(case)
-  if (!case %in% c("1","2","3","4")) stop("'case' must be 1, 2, 3, or 4.",call.=FALSE)
+  if (!case %in% c("1","2","3","4")) STOP("'case' must be 1, 2, 3, or 4.")
   ## needed to get around global binding issue
   b <- b
   ## check t1 and t3
   if (length(t)==1) {
-    if (is.null(t1)) stop("Must provide a 't1' if 't' is only one value.",call.=FALSE)
-    if (is.null(t3)) stop("Must provide a 't3' if 't' is only one value.",call.=FALSE)
+    if (is.null(t1)) STOP("Must provide a 't1' if 't' is only one value.")
+    if (is.null(t3)) STOP("Must provide a 't3' if 't' is only one value.")
   } else {
     if (is.null(t1)) t1 <- min(t,na.rm=TRUE)
     if (is.null(t3)) t3 <- max(t,na.rm=TRUE)
   }
-  if (t1==t3) stop("'t1' cannot equal 't3'.",call.=FALSE)
+  if (t1==t3) STOP("'t1' cannot equal 't3'.")
   if (t1>t3) {
-    warning("'t1' was greater than 't3'; values reversed.",call.=FALSE)
+    WARN("'t1' was greater than 't3'; values reversed.")
     tmp <- t3
     t3 <- t1
     t1 <- tmp
   }
   ## check L1 and L3
-  if (L1>L3) stop ("'L1' cannot be greater than 'L3'",call.=FALSE)
+  if (L1>L3) stop ("'L1' cannot be greater than 'L3'")
   ## Compute values based on case
   switch(case,
          "1"={ val <- ((L1^b)+((L3^b)-(L1^b))*((1-exp(-a*(t-t1)))/(1-exp(-a*(t3-t1)))))^(1/b) },
@@ -1040,13 +1060,16 @@ growthFunShow <- function(type=c("vonBertalanffy","Gompertz","Richards","Logisti
 ################################################################################
 iSGF_VB <- function(param=c("Original","original","vonBertalanffy",
                            "Typical","typical","Traditional","traditional","BevertonHolt",
-                           "GallucciQuinn","GQ","Mooij","Weisberg",
+                           "GallucciQuinn","GQ","Mooij","Weisberg","Ogle",
                            "Schnute","Francis","Laslett","Polacheck",
                            "Somers","Somers2","Pauly",
                            "Fabens","Fabens2","Wang","Wang2","Wang3")) {
-  if(!is.character(param)) stop("'param' must be a character string.",call.=FALSE)
+  if(!is.character(param)) STOP("'param' must be a character string.")
   param <- match.arg(param)
   switch(param,
+    Ogle= {
+      expr <- expression(E(L[t])==L[infinity]~-~(L[infinity]-L[r])*~e^{-K(t~-~t[r])})
+    },
     Typical=,typical=,Traditional=,traditional=,BevertonHolt= {
       expr <- expression(E(L[t])==L[infinity]*bgroup("(",1-e^{-K*(t~-~t[0])},")"))
     },
@@ -1108,7 +1131,7 @@ iSGF_VB <- function(param=c("Original","original","vonBertalanffy",
 iSGF_GOMP <- function(param=c("Original","original","Ricker1","Ricker2","Ricker3",
                              "QuinnDeriso1","QuinnDeriso2","QuinnDeriso3","QD1","QD2","QD3",
                              "Troynikov1","Troynikov2")) {
-  if(!is.character(param)) stop("'param' must be a character string.",call.=FALSE)
+  if(!is.character(param)) STOP("'param' must be a character string.")
   param <- match.arg(param)
   switch(param,
     Original=,original= {
@@ -1136,8 +1159,8 @@ iSGF_GOMP <- function(param=c("Original","original","Ricker1","Ricker2","Ricker3
 }
 
 iSGF_RICHARDS <- function(param=1:6) {
-  if (!is.numeric(param)) stop("'param' must be numeric when type='Richards'.",call.=FALSE)
-  if (!param %in% 1:6) stop("'param' must be from 1-6 when type='Richards'.",call.=FALSE)
+  if (!is.numeric(param)) STOP("'param' must be numeric when type='Richards'.")
+  if (!param %in% 1:6) STOP("'param' must be from 1-6 when type='Richards'.")
   if(param==1){
     expr <- expression(E(L[t])==L[infinity]*~bgroup("(",1-a*e^{-kt},")")^{b})
   } else if (param==2) {
@@ -1155,7 +1178,7 @@ iSGF_RICHARDS <- function(param=1:6) {
 }
 
 iSGF_LOGISTIC <- function(param=c("CJ1","CJ2","Karkach","Haddon","CampanaJones1","CampanaJones2")) {
-  if(!is.character(param)) stop("'param' must be a character string.",call.=FALSE)
+  if(!is.character(param)) STOP("'param' must be a character string.")
   param <- match.arg(param)
   switch(param,
     CJ1=,CampanaJones1= {
@@ -1174,8 +1197,8 @@ iSGF_LOGISTIC <- function(param=c("CJ1","CJ2","Karkach","Haddon","CampanaJones1"
 }
 
 iSGF_SCHNUTE <- function(case=1:4) {
-  if (!is.numeric(case)) stop("'case' must be numeric when type='Schnute'.",call.=FALSE)
-  if (!case %in% 1:4) stop("'case' must be from 1-4 when type='Schnute'.",call.=FALSE)
+  if (!is.numeric(case)) STOP("'case' must be numeric when type='Schnute'.")
+  if (!case %in% 1:4) STOP("'case' must be from 1-4 when type='Schnute'.")
   if(case==1){
     expr <- expression(E(L[t])==bgroup("[",L[1]^{b}+(L[3]^{b}-L[1]^{b})*~frac(1-e^{-a*(~t~-~t[1])},1-e^{-a*(~t[3]~-~t[1])}),"]")^{~frac(1,b)})
   } else if (case==2) {
