@@ -39,10 +39,11 @@
 #' fail <- factor(c(2,2,2,2,1,1,1,1,1,1,2,1,2,1,1,1,1,2,1,1,1,1,1),
 #' levels = 1:2, labels = c("no","yes"))
 #' temperature <- c(53,57,58,63,66,67,67,67,68,69,70,70,70,70,72,73,75,75,76,76,78,79,81)
-#' d <- data.frame(fail,temperature)
+#' d <- data.frame(temperature,fail,fail2=factor(fail,levels=c("yes","no")))
 #'
 #' ## Default plot (using formula notation)
 #' plotBinResp(fail~temperature,data=d)
+#' plotBinResp(fail2~temperature,data=d)
 #'
 #' ## Controlling where proportions are computed with a sequence in breaks
 #' plotBinResp(fail~temperature,data=d,breaks=seq(50,85,5))
@@ -70,9 +71,9 @@
 #'
 #' @rdname plotBinResp
 #' @export
-plotBinResp <- function(x,...) {
+plotBinResp <- function(x,...) { # nocov start
   UseMethod("plotBinResp") 
-}
+} # nocov end
 
 #' @rdname plotBinResp
 #' @export
@@ -91,7 +92,7 @@ plotBinResp.default <- function(x,y,
   # adjust for maximum allowable transparency
   if (transparency>500) transparency <- 500
   # plot raw data points
-  graphics::plot(yn~x,pch=16,col=iMakeColor(col.pt,transparency),yaxt="n",xlab=xlab,ylab=ylab,...)
+  graphics::plot(yn~x,pch=16,col=col2rgbt(col.pt,1/transparency),yaxt="n",xlab=xlab,ylab=ylab,...)
   # puts on ticks
   graphics::axis(2,yaxis1.ticks,FALSE,cex.axis=graphics::par()$cex.axis)
   # only label a few
