@@ -8,7 +8,7 @@
 #' 
 #' If \code{outlier.test=TRUE} then significant outliers are detected with \code{\link[car]{outlierTest}} from the \pkg{car} package.  See the help for this function for more details.
 #'
-#' The user can include the model call as a title to the residual plot by using \code{main="MODEL"}.
+#' The user can include the model call as a title to the residual plot by using \code{main="MODEL"}.  This only works for models created wtih \code{lm()}.
 #' 
 #' If the user chooses to add a legend without identifying coordinates for the upper-left corner of the legend (i.e., \code{legend=TRUE}) then the R console is suspended until the user places the legend by clicking on the produced graphic at the point where the upper-left corner of the legend should appear.  A legend will only be placed if the \code{mdl} is an indicator variable regression, even if \code{legend=TRUE}.
 #'
@@ -35,6 +35,8 @@
 #' @param col.loess A numeric or character that indicates the line color to use for loess fit line.  See \code{par}.
 #' @param trans.loess A single numeric that indicates how transparent the loess band should be (larger numbers are more transparent).
 #' @param legend If \code{TRUE}, draw a legend and the user must click in the upper-left corner of where the legend should be placed; if \code{FALSE} do not draw a legend.  If a vector of length 2 then draw the upper left corner of the legend at the coordinates given in the vector of length 2.
+#' @param cex.leg A single numeric values used to represent the character expansion value for the legend.  Ignored if \code{legend=FALSE}.
+#' @param box.lty.leg A single numeric values used to indicate the type of line to use for the box around the legend.  The default is to not plot a box.
 #' @param inclHist A logical that indicates if a second pane that includes the histogram of residuals should be constructed.
 #' @param \dots Other arguments to the generic \code{plot} function.
 #'
@@ -139,13 +141,13 @@ residPlot <- function (object,...) {
 #' @export
 residPlot.lm <- function(object,...) { # nocov start
   object <- iTypeoflm(object)
-  if (object$type=="MLR") stop("Multiple linear regression objects are not supported by residPlot.",call.=FALSE)
+  if (object$type=="MLR") STOP("Multiple linear regression objects are not supported by residPlot.")
   residPlot(object,...)                          
 }  # nocov end
 
 #' @rdname residPlot
 #' @export
-residPlot.SLR <- function(object,xlab="Fitted Values",ylab="Residuals",main=NULL,
+residPlot.SLR <- function(object,xlab="Fitted Values",ylab="Residuals",main="",
                           pch=16,col="black",lty.ref=3,lwd.ref=1,col.ref="black",
                           resid.type=c("raw","standardized","studentized"),
                           outlier.test=TRUE,alpha=0.05,
@@ -176,17 +178,18 @@ residPlot.POLY <- function(object,...) { # nocov start
 
 #' @rdname residPlot
 #' @export
-residPlot.IVR <- function(object,legend="topright",...) {
+residPlot.IVR <- function(object,legend="topright",cex.leg=1,box.lty.leg=0,...) {
   ## Do some checks
-  if (object$ENumNum>1) stop("'residPlot()' cannot handle >1 covariate in an IVR.",call.=FALSE)
-  if (object$EFactNum>2) stop("'resodPlot()' cannot handle >2 factors in an IVR.",call.=FALSE)
+  if (object$ENumNum>1) STOP("'residPlot()' cannot handle >1 covariate in an IVR.")
+  if (object$EFactNum>2) STOP("'resodPlot()' cannot handle >2 factors in an IVR.")
   ## Decide if a one-way or two-way IVR
-  if (object$EFactNum==1) iResidPlotIVR1(object,legend,...)
-  else iResidPlotIVR2(object,legend,...)
+  if (object$EFactNum==1) iResidPlotIVR1(object,legend,cex.leg,box.lty.leg,...)
+  else iResidPlotIVR2(object,legend,cex.leg,box.lty.leg,...)
 }
 
 
-iResidPlotIVR1 <- function(object,legend,xlab="Fitted Values",ylab="Residuals",main=NULL,
+iResidPlotIVR1 <- function(object,legend,cex.leg,box.lty.leg,
+                           xlab="Fitted Values",ylab="Residuals",main="",
                            pch=c(16,21,15,22,17,24,c(3:14)),col="rich",
                            lty.ref=3,lwd.ref=1,col.ref="black",
                            resid.type=c("raw","standardized","studentized"),
@@ -231,7 +234,8 @@ iResidPlotIVR1 <- function(object,legend,xlab="Fitted Values",ylab="Residuals",m
     if (outlier.test) iAddOutlierTestResults(object,fv,r,alpha)
     ### Prepare and place the legend
     if (leg$do.legend) {
-      graphics::legend(x=leg$x,y=leg$y,legend=levels(f1),col=col,pch=pch)
+      graphics::legend(x=leg$x,y=leg$y,legend=levels(f1),col=col,pch=pch,
+                       cex=cex.leg,box.lty=box.lty.leg)
       graphics::box()
     }
   }
@@ -239,7 +243,8 @@ iResidPlotIVR1 <- function(object,legend,xlab="Fitted Values",ylab="Residuals",m
 } # nocov end
 
 
-iResidPlotIVR2 <- function(object,legend,xlab="Fitted Values",ylab="Residuals",main=NULL,
+iResidPlotIVR2 <- function(object,legend,cex.leg,box.lty.leg,
+                           xlab="Fitted Values",ylab="Residuals",main="",
                            pch=c(16,21,15,22,17,24,c(3:14)),col="rich",
                            lty.ref=3,lwd.ref=1,col.ref="black",
                            resid.type=c("raw","standardized","studentized"),
@@ -292,7 +297,8 @@ iResidPlotIVR2 <- function(object,legend,xlab="Fitted Values",ylab="Residuals",m
       lcol <- rep(col,each=num.f2)
       lpch <- rep(pch,times=num.f1)
       levs <- levels(f1:f2)
-      graphics::legend(x=leg$x,y=leg$y,legend=levs,col=lcol,pch=lpch)
+      graphics::legend(x=leg$x,y=leg$y,legend=levs,col=lcol,pch=lpch,
+                       cex=cex.leg,box.lty=box.lty.leg)
       graphics::box()
     }
   }
@@ -301,7 +307,7 @@ iResidPlotIVR2 <- function(object,legend,xlab="Fitted Values",ylab="Residuals",m
 
 #' @rdname residPlot
 #' @export
-residPlot.ONEWAY <- function(object,xlab="Fitted Values",ylab="Residuals",main=NULL,
+residPlot.ONEWAY <- function(object,xlab="Fitted Values",ylab="Residuals",main="",
                              pch=16,col="black",lty.ref=3,lwd.ref=1,col.ref="black",
                              resid.type=c("raw","standardized","studentized"),
                              bp=TRUE,outlier.test=TRUE,alpha=0.05,
@@ -333,7 +339,7 @@ residPlot.ONEWAY <- function(object,xlab="Fitted Values",ylab="Residuals",main=N
 
 #' @rdname residPlot
 #' @export
-residPlot.TWOWAY <- function(object,xlab="Fitted Values",ylab="Residuals",main=NULL,
+residPlot.TWOWAY <- function(object,xlab="Fitted Values",ylab="Residuals",main="",
                              pch=16,col="black",lty.ref=3,lwd.ref=1,col.ref="black",
                              resid.type=c("raw","standardized","studentized"),
                              bp=TRUE,outlier.test=TRUE,alpha=0.05,
@@ -442,7 +448,7 @@ iAddOutlierTestResults <- function(object,fv,r,alpha) {
     else if (out$bonf.p>alpha) num <- 0  # if p>alpha then ... not a significant point
   }
   # If there are significant points to be highlighted then ...
-  if (num>0) {
+  if (num>0) { # nocov start
     # Determine which observation(s) is/are "significant" outlier(s)
     obs <- as.numeric(names(out$bonf.p))
     # Set text position based on sign of r if only one "outlier" is detected
@@ -451,20 +457,18 @@ iAddOutlierTestResults <- function(object,fv,r,alpha) {
     else pos <- plotrix::thigmophobe(fv,r)[obs]
     # place labels
     graphics::text(fv[obs],r[obs],obs,cex=1.1,col="red",pos=pos,xpd=TRUE)
-  }
+  } # nocov end
 }  # end iAddOutlierTestResults internal function
 
 iGetMainTitle <- function(object,main) {
-  if (!is.null(main)) {
-    if (main=="MODEL") {
-      ## user asking to include the model
-      # get formula parts
-      frm.chr <- as.character(stats::formula(object$mdl))
-      # put together as a main title
-      main <- paste(frm.chr[2],frm.chr[1],frm.chr[3])
-    }
+  if (main=="MODEL") {
+    ## user asked to use model
+    # get formula parts (extra spaces are removed)
+    frm.chr <- gsub("\\s+","",as.character(stats::formula(object$mdl)))
+    # put together as a main title
+    main <- paste0(frm.chr[2],frm.chr[1],frm.chr[3])
   }
-  # return the title (will be original if not main="model")
+  # return the title (will be original if not main="MODEL")
   main
 }  # end iGetMainTitle internal function
 
@@ -481,13 +485,13 @@ iHndlResidType <- function(object,resid.type,ylab) {
            )
   } else if (class(object)=="nls") {
     r <- stats::residuals(object)
-    if (resid.type=="studentized") stop("resid.type= cannot be 'studentized' for NLS objects.  Try resid.type='standardized'.",call.=FALSE)
+    if (resid.type=="studentized") STOP("resid.type= cannot be 'studentized' for NLS objects.  Try resid.type='standardized'.")
     else if (resid.type=="standardized") {
       # this follows nlsResiduals() from nlstools
       r <- (r-mean(r))/summary(object)$sigma
     }
   } else {
-    if (resid.type=="studentized") stop("resid.type= cannot be 'studentized' for NLME objects.  Try resid.type='standardized'.",call.=FALSE)
+    if (resid.type=="studentized") STOP("resid.type= cannot be 'studentized' for NLME objects.  Try resid.type='standardized'.")
     else if (resid.type=="standardized") { 
       r <- stats::residuals(object,type="pearson")
     } else {
